@@ -821,7 +821,11 @@ class ADB(object):
             AdbShellError if no such file
         """
         out = self.shell(["ls", "-l", filepath])
-        file_size = int(out.split()[4])
+        try:
+            file_size = int(out.split()[4])
+        except ValueError:
+            # 安卓6.0.1系统得到的结果是[3]为文件大小
+            file_size = int(out.split()[3])
         return file_size
 
     def _cleanup_forwards(self):
@@ -959,11 +963,15 @@ class ADB(object):
         """
         # use adb shell wm size
         displayInfo = {}
-        wm_size = re.search(r'(?P<width>\d+)x(?P<height>\d+)\s*$', self.raw_shell('wm size'))
-        if wm_size:
-            displayInfo = dict((k, int(v)) for k, v in wm_size.groupdict().items())
-            displayInfo['density'] = self._getDisplayDensity(strip=True)
-            return displayInfo
+        try:
+            wm_size = re.search(r'(?P<width>\d+)x(?P<height>\d+)\s*$', self.cmd('shell wm size', timeout=5))
+        except AdbError as e:
+            print(e)
+        else:
+            if wm_size:
+                displayInfo = dict((k, int(v)) for k, v in wm_size.groupdict().items())
+                displayInfo['density'] = self._getDisplayDensity(strip=True)
+                return displayInfo
 
         phyDispRE = re.compile('.*PhysicalDisplayInfo{(?P<width>\d+) x (?P<height>\d+), .*, density (?P<density>[\d.]+).*')
         out = self.raw_shell('dumpsys display')
@@ -998,7 +1006,7 @@ class ADB(object):
 
         # gets C{mPhysicalDisplayInfo} values from dumpsys. This is a method to obtain display dimensions and density
         phyDispRE = re.compile('Physical size: (?P<width>\d+)x(?P<height>\d+).*Physical density: (?P<density>\d+)', re.S)
-        m = phyDispRE.search(self.raw_shell('wm size; wm density'))
+        m = phyDispRE.search(self.cmd('shell wm size; wm density', timeout=3))
         if m:
             for prop in ['width', 'height']:
                 displayInfo[prop] = int(m.group(prop))
@@ -1006,7 +1014,8 @@ class ADB(object):
                 displayInfo[prop] = float(m.group(prop))
             return displayInfo
 
-        return displayInfo
+        if not displayInfo:
+            raise DeviceConnectionError("Getting device screen information timed out")
 
     def _getDisplayDensity(self, strip=True):
         """
@@ -1417,7 +1426,7 @@ class ADB(object):
         interfaces = ('eth0', 'eth1', 'wlan0')
         for i in interfaces:
             ip = get_ip_address_from_interface(i)
-            if ip and not ip.startswith('172.') and not ip.startswith('127.') and not ip.startswith('169.'):
+            if ip and not ip.startswith('127.') and not ip.startswith('169.'):
                 return ip
 
         return None
